<?php

namespace Drupal\ws_event;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\daterange_compact\DateRangeCompactFormatterInterface;
use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
use Drupal\node\NodeInterface;

/**
 * Helper service to work with Event LB data.
 */
class EventDataHelper {

  /**
   * Daterange Compact formats to be used with Events.
   */
  const DATE_RANGE_MEDIUM_FORMAT = 'medium_date_comma_separated';
  const DATE_RANGE_TIME_FORMAT = 'medium_time_only';

  use StringTranslationTrait;

  /**
   * Daterange Compact formatter service.
   *
   * @var \Drupal\daterange_compact\DateRangeCompactFormatterInterface
   */
  protected $daterangeCompact;

  /**
   * Constructs a new EventDataHelper.
   *
   * @param \Drupal\daterange_compact\DateRangeCompactFormatterInterface $daterange_compact
   *   Daterange Compact formatter service.
   */
  public function __construct(
    DateRangeCompactFormatterInterface $daterange_compact
  ) {
    $this->daterangeCompact = $daterange_compact;
  }

  /**
   * Get formatted date range string.
   *
   * @param \Drupal\node\NodeInterface $node
   *   Node entity.
   * @param string $format
   *   Format to be formatted to.
   *
   * @return string
   *   Formatted date string.
   */
  public function getFormattedDateRange(
    NodeInterface $node,
    string $format = self::DATE_RANGE_MEDIUM_FORMAT
  ): string {
    if (!$node->hasField('field_event_dates')) {
      return '';
    }

    // Get dates.
    $start_date = $node->field_event_dates->value;
    $end_date = $node->field_event_dates->end_value ?: $start_date;
    $timezone = date_default_timezone_get();

    $start = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $start_date, DateTimeItemInterface::STORAGE_TIMEZONE);
    $start->setTimezone(timezone_open($timezone));

    $end = DrupalDateTime::createFromFormat(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $end_date, DateTimeItemInterface::STORAGE_TIMEZONE);
    $end->setTimezone(timezone_open($timezone));

    return (string) $this->daterangeCompact
      ->formatDateRange((string) $start, (string) $end, $format);
  }

}
