<?php

namespace Drupal\ws_event\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Event Contacts block.
 *
 * @Block(
 *   id = "lb_event_contacts",
 *   admin_label = @Translation("Event Contacts"),
 *   category = @Translation("Event blocks")
 * )
 */
class EventContactsBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * Current node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $node;

  /**
   * Node from field_event_location field
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $location;

  /**
   * Constructs a new EventLocationsBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $currentRouteMatch) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $currentRouteMatch;
    $this->node = $currentRouteMatch->getParameter('node');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->node) {
      return [];
    }

    $locationName = $this->node->field_contact_name->value ?? $this->getLocationField('title');
    $phone = $this->node->field_contact_phone->value ?? $this->getLocationField('field_contact_phone');
    $email = $this->node->field_contact_email->value ?? $this->getLocationField('field_location_email');

    $build = [
      '#location_name' => $locationName,
      '#phone' => $phone,
      '#fax' => $this->getLocationField('field_location_fax'),
      '#email' => !empty($email) ? Link::fromTextAndUrl(
        $email,
        Url::fromUri('mailto:' . $email,
          ['attributes' => ['target' => '_blank']])
      ) : '',
    ];

    return $build;
  }

  /**
   * Get field from location (related node)
   *
   * @param string $fieldName location field
   * @return string field value
   */
  protected function getLocationField($fieldName) {

    if (!$this->location) {
      if (!$this->node->hasField('field_location_reference') ||
        $this->node->get('field_event_location')->isEmpty()) {
        return '';
      }
      $this->location = $this->node->get('field_event_location')->entity;
    }
    return $this->location->hasField($fieldName) ? $this->location->$fieldName->value : '';
  }

}
